
# Slot: multivalued


true means that slot can have more than one value

URI: [linkml:multivalued](https://w3id.org/linkml/multivalued)


## Domain and Range

slot_definition &#8594;  <sub>0..1</sub> boolean

## Parents


## Children


## Used by

 * slot_definition
